@@ -26,7 +26,7 @@ def setup():
     codefile = pathlib.Path(FILE_NAME)
 
     # Create commit on master
-    cli.info("Implementing the subtract incorrectly on master.")
+    cli.info("Implementing the subtract function incorrectly on master.")
     code = codefile.read_text()
     implemented_subtract = code.replace(
         """
